;;; session.lisp --- Session helper functions

(defun global-flag-equals? (flag value)
  "Check if global FLAG is equal to VALUE."
  (eq? (get-global-flag flag) value))

(defun global-flag? (flag)
  "Check if a global flag is enabled (equal to 1)"
  (global-flag-equals? flag "1"))

; [todo] - These might end up being removed...

(defun flag? (flag)
  "Check if a global OR local flag is enabled"
  (or
   (eq? (get-global-flag flag) "1")
   (eq? (get-local-flag flag) "1")))

(defun session:get (name &key (type nil))
  "Get the value of NAME from the global session."
  (session:send-signal :GET name type))

(defun session:set (name value)
  "Set the value of NAME to VALUE"
  (session:send-signal :SET name value))

(defun session:increase-value (name &key (value 1))
  "Increase the value of NAME by optional VALUE (defaults to 1)."
  (session:set name (+ (session:get name :TYPE :INT) value)))

(defun session:decrease-value (name &key (value 1))
  "Decrease the value of NAME by optional VALUE (defaults to 1)."
  (session:set name (- (session:get name :TYPE :INT) value)))
